import axios from '../config/axiosConfig'

import { AxiosRequestConfig, CustomSuccessData } from 'axios';
import { getValue } from '@/utils/common';
import { message } from 'ant-design-vue';
import router from '@/router';
import { MessageType } from 'ant-design-vue/types/message';

// 泛型接口 
export interface Get {
    <T>(url: string, params?: unknown, config?: AxiosRequestConfig): Promise<CustomSuccessData<T>>;
}
const login:MessageType[] = []
axios.interceptors.request.use((config)=>{
    login.push(message.loading('加载中..', 0))
    return config;
})

axios.interceptors.response.use((response)=>{
    // console.log(response)
    login[0]();
    login.splice(0,1);
    if(response.data.code == 1001){
        router.push("/")
    }
    return response;
},(error)=>{
    login[0]();
    login.splice(0,1);
    message.error(error.response.data.message)
    return Promise.reject(error) 
})

const get: Get = async function (url: string, data?: unknown) {
    const res =  await axios.get(url, {params:data});
    return res.data;
}

const post: Get = async function (url: string, data?: unknown) {
    const res =  await axios.post(url, data)
    return res.data;
}

const del: Get = async function (url: string, data?: unknown){
    const res =  await axios.delete(url, {params:data})
    return res.data;
}

const put: Get = async function (url: string, data?: unknown){
    const res =  await axios.put(url, data)
    return res.data;
}


function setToken(){
    axios.defaults.headers.common['Authorization'] = "Bearer " + getValue("token");
}

export {
    get,
    post,
    del,
    put,
    setToken
}